pub trait DigestSigner<D: Update, S> {
// Required method
fn try_sign_digest<F: Fn(&mut D) -> Result<(), Error>>(
&self,
f: F,
) -> Result<S, Error>;
// Provided method
fn sign_digest<F: Fn(&mut D)>(&self, f: F) -> S { ... }
}Expand description
Sign the given prehashed message Digest using Self.
Notes
This trait is primarily intended for signature algorithms based on the Fiat-Shamir heuristic, a method for converting an interactive challenge/response-based proof-of-knowledge protocol into an offline digital signature through the use of a random oracle, i.e. a digest function.
The security of such protocols critically rests upon the inability of an attacker to solve for the output of the random oracle, as generally otherwise such signature algorithms are a system of linear equations and therefore doing so would allow the attacker to trivially forge signatures.
To prevent misuse which would potentially allow this to be possible, this API accepts a Digest
instance, rather than a raw digest value.
Required Methods
Sourcefn try_sign_digest<F: Fn(&mut D) -> Result<(), Error>>(
&self,
f: F,
) -> Result<S, Error>
fn try_sign_digest<F: Fn(&mut D) -> Result<(), Error>>( &self, f: F, ) -> Result<S, Error>
Attempt to sign a message by updating the received Digest with it, returning a digital
signature on success, or an error if something went wrong.
The given function can be invoked multiple times. It is expected that in each invocation the
Digest is updated with the entire equal message.
Errors
Returns implementation-specific errors in the event signing failed (e.g. KMS or HSM communication error).
Provided Methods
Sourcefn sign_digest<F: Fn(&mut D)>(&self, f: F) -> S
fn sign_digest<F: Fn(&mut D)>(&self, f: F) -> S
Sign a message by updating the received Digest with it, returning a signature.
The given function can be invoked multiple times. It is expected that in each invocation the
Digest is updated with the entire equal message.
Panics
In the event of a signing error.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.